@@ -49,14 +49,13 @@ const CharacterListRow = new Lang.Class({
 
     _init: function(params) {
         let filtered = Params.filter(params, { characters: null,
-                                               fontDescription: null });
+                                               fontDescription: null,
+                                               overlayFontDescription: null });
         params = Params.fill(params, {});
         this.parent(params);
         this._characters = filtered.characters;
         this._fontDescription = filtered.fontDescription;
-        var fontDescription = filtered.fontDescription.copy();
-        fontDescription.set_size(fontDescription.get_size() * 0.18);
-        this._overlayFontDescription = fontDescription;
+        this._overlayFontDescription = filtered.overlayFontDescription;
     },
 
     draw: function(cr, x, y, width, height) {
@@ -260,9 +259,13 @@ const CharacterListWidget = new Lang.Class({
     },
 
     _createCharacterListRow: function(characters) {
+        var context = this.get_pango_context();
+        var fontDescription = context.get_font_description();
+        fontDescription.set_size(fontDescription.get_size() * 0.8);
         let row = new CharacterListRow({
             characters: characters,
-            fontDescription: this._fontDescription
+            fontDescription: this._fontDescription,
+            overlayFontDescription: fontDescription
         });
         return row;
     },
@@ -504,7 +507,7 @@ const CharacterListView = new Lang.Class({
 
     searchByKeywords: function(keywords) {
         this._characters = [];
-        let criteria = Gc.SearchCriteria.new_keywords(keywords);
+        let criteria = Gc.SearchCriteria.new_keywords(keywords, Gc.SearchFlag.NONE);
         this._searchContext = new Gc.SearchContext({ criteria: criteria });
         this._searchWithContext(this._searchContext, MAX_SEARCH_RESULTS);
     },
